<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>EditShare</name>
    <message>
        <location filename="../editshare.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diàleg</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="20"/>
        <source>&amp;Name</source>
        <translation>&amp;Nom</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="30"/>
        <source>...</source>
        <translation>... </translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="37"/>
        <source>&amp;Path</source>
        <translation>Camí</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="51"/>
        <source>Yes</source>
        <translation>Sí </translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="56"/>
        <source>No</source>
        <translation>No </translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="64"/>
        <source>&amp;Comment</source>
        <translation>&amp;Comentari</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="77"/>
        <source>&amp;Guest OK</source>
        <translation>&amp;Guest correcte</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="111"/>
        <source>Access rights for valid users</source>
        <translation>Drets d&apos;accés per als usuaris vàlids</translation>
    </message>
    <message>
        <location filename="../editshare.cpp" line="46"/>
        <source>Select directory to share</source>
        <translation>Trieu el directori a compartir</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>&amp;Shares</source>
        <translation>Compartit&amp;s</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <source>Shares</source>
        <translation>Comparticions</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No he trobat compartits Samba&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <location filename="../mainwindow.ui" line="157"/>
        <source>&amp;Remove</source>
        <translation>T&amp;reu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <location filename="../mainwindow.ui" line="164"/>
        <source>&amp;Add</source>
        <translation>&amp;Afegeix</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Edit</source>
        <translation>E&amp;dita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Name</source>
        <translation>Nom </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Path</source>
        <translation>Camí</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Comment</source>
        <translation>Comentari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Permissions</source>
        <translation>Permisos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Guest OK</source>
        <translation>Guest correcte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="142"/>
        <source>&amp;Users</source>
        <translation>&amp;Usuaris</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No he trobat cap usuari samba&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Password</source>
        <translation>&amp;Contrasenya</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Users</source>
        <translation>Usuaris </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <location filename="../mainwindow.cpp" line="311"/>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>E&amp;nable Automatic Samba Startup</source>
        <translation>Acti&amp;va l&apos;engegada automàtica de Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <location filename="../mainwindow.cpp" line="288"/>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Star&amp;t Samba</source>
        <translation>En&amp;gega Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Samba autostart service is disabled</source>
        <translation>L&apos;engegada automàtica de Samba està desactivada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Samba is running</source>
        <translation>Samba s&apos;està executant</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>About this application</source>
        <translation>Quant aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>A&amp;bout...</source>
        <translation>&amp;Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="366"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <location filename="../mainwindow.cpp" line="98"/>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="274"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="385"/>
        <location filename="../mainwindow.cpp" line="412"/>
        <location filename="../mainwindow.cpp" line="416"/>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="428"/>
        <location filename="../mainwindow.cpp" line="458"/>
        <location filename="../mainwindow.cpp" line="464"/>
        <location filename="../mainwindow.cpp" line="478"/>
        <location filename="../mainwindow.cpp" line="488"/>
        <location filename="../mainwindow.cpp" line="511"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>Error, could not add share. Empty share name</source>
        <translation>Error, no he pogut afegir el compartit. El nom està buit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>Path: %1 doesn&apos;t exist.</source>
        <translation>El camí: %1 no existeix.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <source>Yes</source>
        <translation>Sí </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>Could not add share. Error message:

%1</source>
        <translation>No he pogut afegir el compartit. Missatge d&apos;error:

%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Error listing users</source>
        <translation>Error llistant usuaris</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>&amp;Deny</source>
        <translation>&amp;Denega</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>&amp;Read Only</source>
        <translation>Només &amp;Lectura</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="185"/>
        <source>&amp;Full Access</source>
        <translation>Accés &amp;Total</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>Error listing shares</source>
        <translation>Error llistant compartits</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
        <translation>El vostre usuari no pertany al grup &apos;sambashare&apos;. Si acabeu d&apos;instal·lar l&apos;aplicació, potser us cal tornar a engegar el sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Sto&amp;p Samba</source>
        <translation>At&amp;ura Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>Samba is not running</source>
        <translation>Samba no s&apos;està executant</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Samba not installed</source>
        <translation>No s&apos;ha instal·lat Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>&amp;Disable Automatic Samba Startup</source>
        <translation>&amp;Desactiva l&apos;engegada automàtica de Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>MX Samba Config</source>
        <translation>MX Samba Config</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Program for configuring Samba shares and users.</source>
        <translation>Programa per configurar els compartits i usuaris de Samba.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Cannot delete user: </source>
        <translation>No puc esborrar l&apos;usuari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Enter the username and password:</source>
        <translation>Entreu el nom d&apos;usuari i la contrasenya: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Username:</source>
        <translation>Nom d&apos;usuari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Password:</source>
        <translation>Contrasenya: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Confirm password:</source>
        <translation>Confirmeu la contrasenya: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>Empty username, please enter a name.</source>
        <translation>Nom d&apos;usuari buit, si us plau entreu un nom.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Matching linux user not found on system, make sure you enter a valid username.</source>
        <translation>No he trobat aquest nom d&apos;usuari linux al sistema, assegureu-vos d&apos;entrar un nom d&apos;usuari vàlid.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Passwords don&apos;t match, please enter again.</source>
        <translation>Les contrasenyes no coincideixen, si us plau torneu a provar-ho.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Could not add user.</source>
        <translation>No puc afegir l&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Change the password for &apos;%1&apos;</source>
        <translation>Canvieu la contrasenya per &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Could not change password.</source>
        <translation>No puc canviar la contrasenya.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Cannot delete share: </source>
        <translation>No puc eliminar el compartit: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Samba service is not running. Please start Samba before adding or editing shares</source>
        <translation>No s&apos;està executant el servei Samba. Si us plau, engegueu Samba abans d&apos;afegir o editar compartits </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Error: trying to process permissions: </source>
        <translation>Error intentant processar els permisos: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>You must run this program as normal user.</source>
        <translation>Cal executar aquest programa com a usuari normal.</translation>
    </message>
</context>
</TS>
